.. image:: https://gitlab.nlx.di.fc.ul.pt/lx/lxcommon/badges/master/pipeline.svg?style=flat
.. image:: https://gitlab.nlx.di.fc.ul.pt/lx/lxcommon/badges/master/coverage.svg?style=flat

LX-Common
=========

LX-Common is a package for code bits shared across several LX tools.
